==> apache-servicecomb-java-chassis-distribution-2.8.28-src.zip: apache-servicecomb-java-chassis-distribution-2.8.28-src/huawei-cloud/dashboard/src/main/java/org/apache/servicecomb/huaweicloud/dashboard/monitor/MonitorBootListener.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.huaweicloud.dashboard.monitor;

import javax.inject.Inject;

import org.apache.servicecomb.core.BootListener;
import org.apache.servicecomb.huaweicloud.dashboard.monitor.data.MonitorConstant;

public class MonitorBootListener implements BootListener {

  @Inject
  private DataFactory dataFactory;

  @Override
  public void onBootEvent(BootEvent event) {
    if (!MonitorConstant.isMonitorEnabled()) {
      return;
    }

    if (EventType.AFTER_REGISTRY == event.getEventType()) {
      dataFactory.start();
    }
  }

  public DataFactory getDataFactory() {
    return dataFactory;
  }

  public void setDataFactory(DataFactory dataFactory) {
    this.dataFactory = dataFactory;
  }
}

==> apache-servicecomb-java-chassis-distribution-2.9.2-src.zip: apache-servicecomb-java-chassis-distribution-2.9.2-src/huawei-cloud/dashboard/src/main/java/org/apache/servicecomb/huaweicloud/dashboard/monitor/MonitorBootListener.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.huaweicloud.dashboard.monitor;

import org.apache.servicecomb.core.BootListener;
import org.apache.servicecomb.huaweicloud.dashboard.monitor.data.MonitorConstant;

import jakarta.inject.Inject;

public class MonitorBootListener implements BootListener {

  @Inject
  private DataFactory dataFactory;

  @Override
  public void onBootEvent(BootEvent event) {
    if (!MonitorConstant.isMonitorEnabled()) {
      return;
    }

    if (EventType.AFTER_REGISTRY == event.getEventType()) {
      dataFactory.start();
    }
  }

  public DataFactory getDataFactory() {
    return dataFactory;
  }

  public void setDataFactory(DataFactory dataFactory) {
    this.dataFactory = dataFactory;
  }
}
